<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml" version="1.0">
	<xsl:output indent="no" method="text"  encoding="iso-8859-1"/>

<xsl:template match="/">
	<xsl:apply-templates select="beans_cmf"/>
</xsl:template>


<xsl:template match="beans_cmf">

## Copyright (C) 2001, Makina Corpus, http://makina-corpus.org
## Maintained by Alexandre Passant 
## Released under GPL version 2
## See LICENSE.txt or http://www.gnu.org/copyleft/gpl.html

__version__ = "<xsl:value-of select="version"/>"
__doc__ = """<xsl:value-of select="doc"/>"""

## ZOPE imports
from Globals import InitializeClass
from AccessControl import ClassSecurityInfo
import OFS.Image

##  CMF imports
from Products.CMFDefault.DublinCore import DefaultDublinCoreImpl
from Products.CMFCore.WorkflowCore import WorkflowAction
from Products.CMFCore import CMFCorePermissions
from Products.CMFDefault.File import File
from Products.CMFCore.PortalContent import PortalContent

#####################################
## <xsl:value-of select="fti/description"/> properties and methods ##
#####################################

factory_type_information = (
	{'id'		: '<xsl:value-of select="fti/id"/>',
	'meta_type'	: '<xsl:value-of select="fti/meta_type"/>',
	'description'	: ('<xsl:value-of select="fti/description"/>'),
	'product'	: '<xsl:value-of select="fti/product"/>',
	'factory'	: 'addCMFTutorial',
	'immediate_view': 'metadata_edit_form',
	'actions'	: (
		{'id'		: 'view',
		 'name'		: 'View',
		 'action'	: '<xsl:value-of select="fti/skin_action"/>_view',
		 'permissions'	: (CMFCorePermissions.View,),
	        },
	        {'id'		: 'edit',
		 'name'		: 'Edit',
		 'action'	: '<xsl:value-of select="fti/skin_action"/>_edit_form',
                 'permissions'	: (CMFCorePermissions.ModifyPortalContent,),
		},
		{ 'id'		: 'metadata',
		  'name'	: 'Metadata',
		  'action'	: 'metadata_edit_form',
                  'permissions' : (CMFCorePermissions.ModifyPortalContent,),
		},
		),
	},
)


def addCMFTutorial(self,
		<xsl:call-template name="var1"/>):
				
	""" Create an empty <xsl:value-of select="fti/product"/> """
	aindexer_object = <xsl:value-of select="fti/product"/>(id,
					title, 
					description,
					<xsl:call-template name="var2"/>)
	self._setObject(id, aindexer_object)

class <xsl:value-of select="fti/product"/>(DefaultDublinCoreImpl, 
		PortalContent,
		OFS.Image.File,
		File,
		):
	
	""" <xsl:value-of select="fti/product"/> Class """

	meta_type = '<xsl:value-of select="fti/meta_type"/>'

 	ClassSecurityInfo().declareObjectPublic()

   	def __init__(self, 
			id, 
			title='', 
			description='',
			file='',
			<xsl:call-template name="var3"/>):

	        """ Initialize an instance of the class """

		## parents constructors 
        	DefaultDublinCoreImpl.__init__(self, title, description = description)

		## set infos

		self.id = id
		<xsl:call-template name="var4"/>

	def edit(self,
		file='', 
		<xsl:call-template name="var1"/>):		


		""" Edit the instance's properties """

		## update infos
		<xsl:call-template name="var4"/>
		
		## upload file + get infos
		if self._isNotEmpty(file):
			self.manage_upload(file)	
			self.filename = file.filename
			self.filetype = filetype or self._getType(file.headers)
				
	edit = WorkflowAction(edit) 

	def SearchableText(self):
		""" Method used by search engine """
		return "%s %s %s %s  %s" %(self.title <xsl:call-template name="var5"/>)


	def index_html(self, REQUEST, RESPONSE):
		""" Force tutorial download with correct filename """
		RESPONSE.setHeader('Content-Disposition', 'attachement; filename="%s"' %self.filename)
		return OFS.Image.File.index_html(self, REQUEST, RESPONSE)



##############################################
## Internal methods // not used ZOPE or CMF ##
##############################################

	def _getType(self, headers):
		""" get file type (or content-type) """
		import string
		if headers is not None:
			## convert headers to dict
			dic = {}
			for i in headers.headers :
				x = string.split(i,':')
				if len(x) == 2 :
					dic[string.upper(x[0])]=x[1][1:]	
			## get type in original format (eg: application/pdf)
			type = dic['CONTENT-TYPE']
			## some frequent document types  / conversion
			## OpenOffice types not referenced yet :(
			if string.find(type, 'html') != -1 :
				return 'HTML document'
			elif string.find(type, 'text') != -1 :
				return 'Text file'
			elif string.find(type, 'pdf') != -1 :
				return 'PDF document'
			elif string.find(type, 'dvi') != -1 :
				return 'DVI document'
			elif string.find(type, 'postscript') != -1 :
				return 'Postscript file'
			elif string.find(type, 'tex') != -1 :
				return 'TeX file'
			elif string.find(type, 'xml') != -1 :
				return 'XML document'
			elif string.find(type, 'zip') != -1 :
				return 'Zip file'
			elif string.find(type, 'gzip') != -1 :
				return 'GZip file'
			elif string.find(type, 'msword') != -1 :
				return 'Word document'
			elif string.find(type, 'excel') != -1 :
				return 'Excel sheet'
			elif string.find(type, 'powerpoint') != -1 :
				return 'Powerpoint document'
			else :
				return 'Unknown document type (%s)' %type
		else:
			return 'Unknown document type'
	
	
##########################
## Class Initialisation ##
##########################

InitializeClass(<xsl:value-of select="fti/product"/>)
		

</xsl:template>

<xsl:template name="var1">
		<xsl:for-each select="class/property">
		<xsl:value-of select="."/> = '',
		</xsl:for-each>
</xsl:template>

<xsl:template name="var2">
					<xsl:for-each select="class/property">
					<xsl:value-of select="."/> = '',
					</xsl:for-each>

</xsl:template>

<xsl:template name="var3">
			<xsl:for-each select="class/property">
			<xsl:value-of select="."/> = '',
			</xsl:for-each>
</xsl:template>

<xsl:template name="var4">
		<xsl:for-each select="class/property">
		self.<xsl:value-of select="."/> = <xsl:value-of select="."/>
		</xsl:for-each>
</xsl:template>

<xsl:template name="var5"> <xsl:for-each select="class/property"> , <xsl:value-of select="."/> = '' </xsl:for-each></xsl:template>


</xsl:stylesheet>
